@@ -9,7 +9,7 @@ import (
 )
 
 func testRunTag(t testing.TB, opts TagOptions, gopts GlobalOptions) {
-	rtest.OK(t, runTag(context.TODO(), opts, gopts, []string{}))
+	rtest.OK(t, runTag(context.TODO(), opts, gopts, nil, []string{}))
 }
 
 // nolint: staticcheck // false positive nil pointer dereference check
