@@ -3,14 +3,18 @@ package main
 import (
 	"context"
 
-	"github.com/restic/restic/internal/restic"
+	"github.com/restic/restic/internal/repository"
 	"github.com/spf13/cobra"
+	"github.com/spf13/pflag"
 )
 
-var unlockCmd = &cobra.Command{
-	Use:   "unlock",
-	Short: "Remove locks other processes created",
-	Long: `
+func newUnlockCommand() *cobra.Command {
+	var opts UnlockOptions
+
+	cmd := &cobra.Command{
+		Use:   "unlock",
+		Short: "Remove locks other processes created",
+		Long: `
 The "unlock" command removes stale locks that have been created by other restic processes.
 
 EXIT STATUS
@@ -19,11 +23,14 @@ EXIT STATUS
 Exit status is 0 if the command was successful.
 Exit status is 1 if there was any error.
 `,
-	GroupID:           cmdGroupDefault,
-	DisableAutoGenTag: true,
-	RunE: func(cmd *cobra.Command, _ []string) error {
-		return runUnlock(cmd.Context(), unlockOptions, globalOptions)
-	},
+		GroupID:           cmdGroupDefault,
+		DisableAutoGenTag: true,
+		RunE: func(cmd *cobra.Command, _ []string) error {
+			return runUnlock(cmd.Context(), opts, globalOptions)
+		},
+	}
+	opts.AddFlags(cmd.Flags())
+	return cmd
 }
 
 // UnlockOptions collects all options for the unlock command.
@@ -31,12 +38,8 @@ type UnlockOptions struct {
 	RemoveAll bool
 }
 
-var unlockOptions UnlockOptions
-
-func init() {
-	cmdRoot.AddCommand(unlockCmd)
-
-	unlockCmd.Flags().BoolVar(&unlockOptions.RemoveAll, "remove-all", false, "remove all locks, even non-stale ones")
+func (opts *UnlockOptions) AddFlags(f *pflag.FlagSet) {
+	f.BoolVar(&opts.RemoveAll, "remove-all", false, "remove all locks, even non-stale ones")
 }
 
 func runUnlock(ctx context.Context, opts UnlockOptions, gopts GlobalOptions) error {
@@ -45,9 +48,9 @@ func runUnlock(ctx context.Context, opts UnlockOptions, gopts GlobalOptions) err
 		return err
 	}
 
-	fn := restic.RemoveStaleLocks
+	fn := repository.RemoveStaleLocks
 	if opts.RemoveAll {
-		fn = restic.RemoveAllLocks
+		fn = repository.RemoveAllLocks
 	}
 
 	processed, err := fn(ctx, repo)
