@@ -4,6 +4,7 @@ import (
 	"bufio"
 	"bytes"
 	"context"
+	"encoding/json"
 	"fmt"
 	"log"
 	"os"
@@ -16,7 +17,6 @@ import (
 	"github.com/restic/restic/internal/debug"
 	"github.com/restic/restic/internal/errors"
 	"github.com/restic/restic/internal/feature"
-	"github.com/restic/restic/internal/options"
 	"github.com/restic/restic/internal/repository"
 	"github.com/restic/restic/internal/restic"
 )
@@ -28,66 +28,29 @@ func init() {
 
 var ErrOK = errors.New("ok")
 
-// cmdRoot is the base command when no other command has been specified.
-var cmdRoot = &cobra.Command{
-	Use:   "restic",
-	Short: "Backup and restore files",
-	Long: `
+var cmdGroupDefault = "default"
+var cmdGroupAdvanced = "advanced"
+
+func newRootCommand() *cobra.Command {
+	cmd := &cobra.Command{
+		Use:   "restic",
+		Short: "Backup and restore files",
+		Long: `
 restic is a backup program which allows saving multiple revisions of files and
 directories in an encrypted repository stored on different backends.
 
 The full documentation can be found at https://restic.readthedocs.io/ .
 `,
-	SilenceErrors:     true,
-	SilenceUsage:      true,
-	DisableAutoGenTag: true,
+		SilenceErrors:     true,
+		SilenceUsage:      true,
+		DisableAutoGenTag: true,
 
-	PersistentPreRunE: func(c *cobra.Command, _ []string) error {
-		// set verbosity, default is one
-		globalOptions.verbosity = 1
-		if globalOptions.Quiet && globalOptions.Verbose > 0 {
-			return errors.Fatal("--quiet and --verbose cannot be specified at the same time")
-		}
+		PersistentPreRunE: func(c *cobra.Command, _ []string) error {
+			return globalOptions.PreRun(needsPassword(c.Name()))
+		},
+	}
 
-		switch {
-		case globalOptions.Verbose >= 2:
-			globalOptions.verbosity = 3
-		case globalOptions.Verbose > 0:
-			globalOptions.verbosity = 2
-		case globalOptions.Quiet:
-			globalOptions.verbosity = 0
-		}
-
-		// parse extended options
-		opts, err := options.Parse(globalOptions.Options)
-		if err != nil {
-			return err
-		}
-		globalOptions.extended = opts
-		if !needsPassword(c.Name()) {
-			return nil
-		}
-		pwd, err := resolvePassword(globalOptions, "RESTIC_PASSWORD")
-		if err != nil {
-			fmt.Fprintf(os.Stderr, "Resolving password failed: %v\n", err)
-			Exit(1)
-		}
-		globalOptions.password = pwd
-
-		// run the debug functions for all subcommands (if build tag "debug" is
-		// enabled)
-		return runDebug()
-	},
-	PersistentPostRun: func(_ *cobra.Command, _ []string) {
-		stopDebug()
-	},
-}
-
-var cmdGroupDefault = "default"
-var cmdGroupAdvanced = "advanced"
-
-func init() {
-	cmdRoot.AddGroup(
+	cmd.AddGroup(
 		&cobra.Group{
 			ID:    cmdGroupDefault,
 			Title: "Available Commands:",
@@ -97,6 +60,49 @@ func init() {
 			Title: "Advanced Options:",
 		},
 	)
+
+	globalOptions.AddFlags(cmd.PersistentFlags())
+
+	// Use our "generate" command instead of the cobra provided "completion" command
+	cmd.CompletionOptions.DisableDefaultCmd = true
+
+	cmd.AddCommand(
+		newBackupCommand(),
+		newCacheCommand(),
+		newCatCommand(),
+		newCheckCommand(),
+		newCopyCommand(),
+		newDiffCommand(),
+		newDumpCommand(),
+		newFeaturesCommand(),
+		newFindCommand(),
+		newForgetCommand(),
+		newGenerateCommand(),
+		newInitCommand(),
+		newKeyCommand(),
+		newListCommand(),
+		newLsCommand(),
+		newMigrateCommand(),
+		newOptionsCommand(),
+		newPruneCommand(),
+		newRebuildIndexCommand(),
+		newRecoverCommand(),
+		newRepairCommand(),
+		newRestoreCommand(),
+		newRewriteCommand(),
+		newSnapshotsCommand(),
+		newStatsCommand(),
+		newTagCommand(),
+		newUnlockCommand(),
+		newVersionCommand(),
+	)
+
+	registerDebugCommand(cmd)
+	registerMountCommand(cmd)
+	registerSelfUpdateCommand(cmd)
+	registerProfiling(cmd)
+
+	return cmd
 }
 
 // Distinguish commands that need the password from those that work without,
@@ -119,6 +125,30 @@ func tweakGoGC() {
 	}
 }
 
+func printExitError(code int, message string) {
+	if globalOptions.JSON {
+		type jsonExitError struct {
+			MessageType string `json:"message_type"` // exit_error
+			Code        int    `json:"code"`
+			Message     string `json:"message"`
+		}
+
+		jsonS := jsonExitError{
+			MessageType: "exit_error",
+			Code:        code,
+			Message:     message,
+		}
+
+		err := json.NewEncoder(globalOptions.stderr).Encode(jsonS)
+		if err != nil {
+			Warnf("JSON encode failed: %v\n", err)
+			return
+		}
+	} else {
+		_, _ = fmt.Fprintf(globalOptions.stderr, "%v\n", message)
+	}
+}
+
 func main() {
 	tweakGoGC()
 	// install custom global logger into a buffer, if an error occurs
@@ -127,10 +157,10 @@ func main() {
 	log.SetOutput(logBuffer)
 
 	err := feature.Flag.Apply(os.Getenv("RESTIC_FEATURES"), func(s string) {
-		fmt.Fprintln(os.Stderr, s)
+		_, _ = fmt.Fprintln(os.Stderr, s)
 	})
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
+		_, _ = fmt.Fprintln(os.Stderr, err)
 		Exit(1)
 	}
 
@@ -139,32 +169,33 @@ func main() {
 		version, runtime.Version(), runtime.GOOS, runtime.GOARCH)
 
 	ctx := createGlobalContext()
-	err = cmdRoot.ExecuteContext(ctx)
+	err = newRootCommand().ExecuteContext(ctx)
 
 	if err == nil {
 		err = ctx.Err()
 	} else if err == ErrOK {
-		// ErrOK overwrites context cancelation errors
+		// ErrOK overwrites context cancellation errors
 		err = nil
 	}
 
+	var exitMessage string
 	switch {
 	case restic.IsAlreadyLocked(err):
-		fmt.Fprintf(os.Stderr, "%v\nthe `unlock` command can be used to remove stale locks\n", err)
+		exitMessage = fmt.Sprintf("%v\nthe `unlock` command can be used to remove stale locks", err)
 	case err == ErrInvalidSourceData:
-		fmt.Fprintf(os.Stderr, "Warning: %v\n", err)
+		exitMessage = fmt.Sprintf("Warning: %v", err)
 	case errors.IsFatal(err):
-		fmt.Fprintf(os.Stderr, "%v\n", err)
+		exitMessage = err.Error()
 	case errors.Is(err, repository.ErrNoKeyFound):
-		fmt.Fprintf(os.Stderr, "Fatal: %v\n", err)
+		exitMessage = fmt.Sprintf("Fatal: %v", err)
 	case err != nil:
-		fmt.Fprintf(os.Stderr, "%+v\n", err)
+		exitMessage = fmt.Sprintf("%+v", err)
 
 		if logBuffer.Len() > 0 {
-			fmt.Fprintf(os.Stderr, "also, the following messages were logged by a library:\n")
+			exitMessage += "also, the following messages were logged by a library:\n"
 			sc := bufio.NewScanner(logBuffer)
 			for sc.Scan() {
-				fmt.Fprintln(os.Stderr, sc.Text())
+				exitMessage += fmt.Sprintln(sc.Text())
 			}
 		}
 	}
@@ -186,5 +217,9 @@ func main() {
 	default:
 		exitCode = 1
 	}
+
+	if exitCode != 0 {
+		printExitError(exitCode, exitMessage)
+	}
 	Exit(exitCode)
 }
