@@ -37,15 +37,10 @@ func NewFactory() location.Factory {
 	return location.NewLimitedBackendFactory("local", ParseConfig, location.NoPassword, limiter.WrapBackendConstructor(Create), limiter.WrapBackendConstructor(Open))
 }
 
-const defaultLayout = "default"
+func open(cfg Config) (*Local, error) {
+	l := layout.NewDefaultLayout(cfg.Path, filepath.Join)
 
-func open(ctx context.Context, cfg Config) (*Local, error) {
-	l, err := layout.ParseLayout(ctx, &layout.LocalFilesystem{}, cfg.Layout, defaultLayout, cfg.Path)
-	if err != nil {
-		return nil, err
-	}
-
-	fi, err := fs.Stat(l.Filename(backend.Handle{Type: backend.ConfigFile}))
+	fi, err := os.Stat(l.Filename(backend.Handle{Type: backend.ConfigFile}))
 	m := util.DeriveModesFromFileInfo(fi, err)
 	debug.Log("using (%03O file, %03O dir) permissions", m.File, m.Dir)
 
@@ -57,30 +52,30 @@ func open(ctx context.Context, cfg Config) (*Local, error) {
 }
 
 // Open opens the local backend as specified by config.
-func Open(ctx context.Context, cfg Config) (*Local, error) {
-	debug.Log("open local backend at %v (layout %q)", cfg.Path, cfg.Layout)
-	return open(ctx, cfg)
+func Open(_ context.Context, cfg Config) (*Local, error) {
+	debug.Log("open local backend at %v", cfg.Path)
+	return open(cfg)
 }
 
 // Create creates all the necessary files and directories for a new local
 // backend at dir. Afterwards a new config blob should be created.
-func Create(ctx context.Context, cfg Config) (*Local, error) {
-	debug.Log("create local backend at %v (layout %q)", cfg.Path, cfg.Layout)
+func Create(_ context.Context, cfg Config) (*Local, error) {
+	debug.Log("create local backend at %v", cfg.Path)
 
-	be, err := open(ctx, cfg)
+	be, err := open(cfg)
 	if err != nil {
 		return nil, err
 	}
 
 	// test if config file already exists
-	_, err = fs.Lstat(be.Filename(backend.Handle{Type: backend.ConfigFile}))
+	_, err = os.Lstat(be.Filename(backend.Handle{Type: backend.ConfigFile}))
 	if err == nil {
 		return nil, errors.New("config file already exists")
 	}
 
 	// create paths for data and refs
 	for _, d := range be.Paths() {
-		err := fs.MkdirAll(d, be.Modes.Dir)
+		err := os.MkdirAll(d, be.Modes.Dir)
 		if err != nil {
 			return nil, errors.WithStack(err)
 		}
@@ -89,8 +84,11 @@ func Create(ctx context.Context, cfg Config) (*Local, error) {
 	return be, nil
 }
 
-func (b *Local) Connections() uint {
-	return b.Config.Connections
+func (b *Local) Properties() backend.Properties {
+	return backend.Properties{
+		Connections:      b.Config.Connections,
+		HasAtomicReplace: true,
+	}
 }
 
 // Hasher may return a hash function for calculating a content hash for the backend
@@ -98,11 +96,6 @@ func (b *Local) Hasher() hash.Hash {
 	return nil
 }
 
-// HasAtomicReplace returns whether Save() can atomically replace files
-func (b *Local) HasAtomicReplace() bool {
-	return true
-}
-
 // IsNotExist returns true if the error is caused by a non existing file.
 func (b *Local) IsNotExist(err error) bool {
 	return errors.Is(err, os.ErrNotExist)
@@ -132,7 +125,7 @@ func (b *Local) Save(_ context.Context, h backend.Handle, rd backend.RewindReade
 		debug.Log("error %v: creating dir", err)
 
 		// error is caused by a missing directory, try to create it
-		mkdirErr := fs.MkdirAll(dir, b.Modes.Dir)
+		mkdirErr := os.MkdirAll(dir, b.Modes.Dir)
 		if mkdirErr != nil {
 			debug.Log("error creating dir %v: %v", dir, mkdirErr)
 		} else {
@@ -152,7 +145,7 @@ func (b *Local) Save(_ context.Context, h backend.Handle, rd backend.RewindReade
 			// temporary's name and no other goroutine will get the same data to
 			// Save, so the temporary name should never be reused by another
 			// goroutine.
-			_ = fs.Remove(f.Name())
+			_ = os.Remove(f.Name())
 		}
 	}(f)
 
@@ -216,7 +209,7 @@ func (b *Local) Load(ctx context.Context, h backend.Handle, length int, offset i
 }
 
 func (b *Local) openReader(_ context.Context, h backend.Handle, length int, offset int64) (io.ReadCloser, error) {
-	f, err := fs.Open(b.Filename(h))
+	f, err := os.Open(b.Filename(h))
 	if err != nil {
 		return nil, err
 	}
@@ -250,7 +243,7 @@ func (b *Local) openReader(_ context.Context, h backend.Handle, length int, offs
 
 // Stat returns information about a blob.
 func (b *Local) Stat(_ context.Context, h backend.Handle) (backend.FileInfo, error) {
-	fi, err := fs.Stat(b.Filename(h))
+	fi, err := os.Stat(b.Filename(h))
 	if err != nil {
 		return backend.FileInfo{}, errors.WithStack(err)
 	}
@@ -263,12 +256,12 @@ func (b *Local) Remove(_ context.Context, h backend.Handle) error {
 	fn := b.Filename(h)
 
 	// reset read-only flag
-	err := fs.Chmod(fn, 0666)
+	err := os.Chmod(fn, 0666)
 	if err != nil && !os.IsPermission(err) {
 		return errors.WithStack(err)
 	}
 
-	return fs.Remove(fn)
+	return os.Remove(fn)
 }
 
 // List runs fn for each file in the backend which has the type t. When an
@@ -294,7 +287,7 @@ func (b *Local) List(ctx context.Context, t backend.FileType, fn func(backend.Fi
 // Also, visitDirs assumes it sees a directory full of directories, while
 // visitFiles wants a directory full or regular files.
 func visitDirs(ctx context.Context, dir string, fn func(backend.FileInfo) error) error {
-	d, err := fs.Open(dir)
+	d, err := os.Open(dir)
 	if err != nil {
 		return err
 	}
@@ -321,7 +314,7 @@ func visitDirs(ctx context.Context, dir string, fn func(backend.FileInfo) error)
 }
 
 func visitFiles(ctx context.Context, dir string, fn func(backend.FileInfo) error, ignoreNotADirectory bool) error {
-	d, err := fs.Open(dir)
+	d, err := os.Open(dir)
 	if err != nil {
 		return err
 	}
@@ -367,7 +360,7 @@ func visitFiles(ctx context.Context, dir string, fn func(backend.FileInfo) error
 
 // Delete removes the repository and all files.
 func (b *Local) Delete(_ context.Context) error {
-	return fs.RemoveAll(b.Path)
+	return os.RemoveAll(b.Path)
 }
 
 // Close closes all open files.
@@ -376,3 +369,9 @@ func (b *Local) Close() error {
 	// same function.
 	return nil
 }
+
+// Warmup not implemented
+func (b *Local) Warmup(_ context.Context, _ []backend.Handle) ([]backend.Handle, error) {
+	return []backend.Handle{}, nil
+}
+func (b *Local) WarmupWait(_ context.Context, _ []backend.Handle) error { return nil }
