@@ -39,8 +39,11 @@ func (d *Dumper) dumpNodeZip(ctx context.Context, node *restic.Node, zw *zip.Wri
 		Modified:           node.ModTime,
 	}
 	header.SetMode(node.Mode)
+	if node.Type == restic.NodeTypeFile {
+		header.Method = zip.Deflate
+	}
 
-	if IsDir(node) {
+	if node.Type == restic.NodeTypeDir {
 		header.Name += "/"
 	}
 
@@ -49,7 +52,7 @@ func (d *Dumper) dumpNodeZip(ctx context.Context, node *restic.Node, zw *zip.Wri
 		return errors.Wrap(err, "ZipHeader")
 	}
 
-	if IsLink(node) {
+	if node.Type == restic.NodeTypeSymlink {
 		if _, err = w.Write([]byte(node.LinkTarget)); err != nil {
 			return errors.Wrap(err, "Write")
 		}
