@@ -10,7 +10,6 @@ import (
 	"os"
 	"path/filepath"
 	"reflect"
-	"strings"
 	"syscall"
 	"testing"
 	"unsafe"
@@ -46,7 +45,7 @@ import (
 // under MIT license.
 
 var (
-	testEas = []ExtendedAttribute{
+	testEas = []extendedAttribute{
 		{Name: "foo", Value: []byte("bar")},
 		{Name: "fizz", Value: []byte("buzz")},
 	}
@@ -58,14 +57,14 @@ var (
 )
 
 func TestRoundTripEas(t *testing.T) {
-	b, err := EncodeExtendedAttributes(testEas)
+	b, err := encodeExtendedAttributes(testEas)
 	if err != nil {
 		t.Fatal(err)
 	}
 	if !reflect.DeepEqual(testEasEncoded, b) {
 		t.Fatalf("Encoded mismatch %v %v", testEasEncoded, b)
 	}
-	eas, err := DecodeExtendedAttributes(b)
+	eas, err := decodeExtendedAttributes(b)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -75,7 +74,7 @@ func TestRoundTripEas(t *testing.T) {
 }
 
 func TestEasDontNeedPaddingAtEnd(t *testing.T) {
-	eas, err := DecodeExtendedAttributes(testEasNotPadded)
+	eas, err := decodeExtendedAttributes(testEasNotPadded)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -85,21 +84,21 @@ func TestEasDontNeedPaddingAtEnd(t *testing.T) {
 }
 
 func TestTruncatedEasFailCorrectly(t *testing.T) {
-	_, err := DecodeExtendedAttributes(testEasTruncated)
+	_, err := decodeExtendedAttributes(testEasTruncated)
 	if err == nil {
 		t.Fatal("expected error")
 	}
 }
 
 func TestNilEasEncodeAndDecodeAsNil(t *testing.T) {
-	b, err := EncodeExtendedAttributes(nil)
+	b, err := encodeExtendedAttributes(nil)
 	if err != nil {
 		t.Fatal(err)
 	}
 	if len(b) != 0 {
 		t.Fatal("expected empty")
 	}
-	eas, err := DecodeExtendedAttributes(nil)
+	eas, err := decodeExtendedAttributes(nil)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -142,7 +141,7 @@ func TestSetGetFileEA(t *testing.T) {
 	testFilePath, testFile := setupTestFile(t)
 	testEAs := generateTestEAs(t, 3, testFilePath)
 	fileHandle := openFile(t, testFilePath, windows.FILE_ATTRIBUTE_NORMAL)
-	defer closeFileHandle(t, testFilePath, testFile, fileHandle)
+	defer testCloseFileHandle(t, testFilePath, testFile, fileHandle)
 
 	testSetGetEA(t, testFilePath, fileHandle, testEAs)
 }
@@ -154,7 +153,7 @@ func TestSetGetFolderEA(t *testing.T) {
 
 	testEAs := generateTestEAs(t, 3, testFolderPath)
 	fileHandle := openFile(t, testFolderPath, windows.FILE_ATTRIBUTE_NORMAL|windows.FILE_FLAG_BACKUP_SEMANTICS)
-	defer closeFileHandle(t, testFolderPath, nil, fileHandle)
+	defer testCloseFileHandle(t, testFolderPath, nil, fileHandle)
 
 	testSetGetEA(t, testFolderPath, fileHandle, testEAs)
 }
@@ -178,8 +177,8 @@ func setupTestFolder(t *testing.T) string {
 	return testfolderPath
 }
 
-func generateTestEAs(t *testing.T, nAttrs int, path string) []ExtendedAttribute {
-	testEAs := make([]ExtendedAttribute, nAttrs)
+func generateTestEAs(t *testing.T, nAttrs int, path string) []extendedAttribute {
+	testEAs := make([]extendedAttribute, nAttrs)
 	for i := 0; i < nAttrs; i++ {
 		testEAs[i].Name = fmt.Sprintf("TESTEA%d", i+1)
 		testEAs[i].Value = make([]byte, getRandomInt())
@@ -212,7 +211,7 @@ func openFile(t *testing.T, path string, attributes uint32) windows.Handle {
 	return fileHandle
 }
 
-func closeFileHandle(t *testing.T, testfilePath string, testFile *os.File, handle windows.Handle) {
+func testCloseFileHandle(t *testing.T, testfilePath string, testFile *os.File, handle windows.Handle) {
 	if testFile != nil {
 		err := testFile.Close()
 		if err != nil {
@@ -231,12 +230,12 @@ func cleanupTestFile(t *testing.T, path string) {
 	}
 }
 
-func testSetGetEA(t *testing.T, path string, handle windows.Handle, testEAs []ExtendedAttribute) {
-	if err := SetFileEA(handle, testEAs); err != nil {
+func testSetGetEA(t *testing.T, path string, handle windows.Handle, testEAs []extendedAttribute) {
+	if err := fsetEA(handle, testEAs); err != nil {
 		t.Fatalf("set EA for path %s failed: %s", path, err)
 	}
 
-	readEAs, err := GetFileEA(handle)
+	readEAs, err := fgetEA(handle)
 	if err != nil {
 		t.Fatalf("get EA for path %s failed: %s", path, err)
 	}
@@ -262,7 +261,7 @@ func TestPathSupportsExtendedAttributes(t *testing.T) {
 
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
-			supported, err := PathSupportsExtendedAttributes(tc.path)
+			supported, err := pathSupportsExtendedAttributes(tc.path)
 			if err != nil {
 				t.Fatalf("Unexpected error: %v", err)
 			}
@@ -273,50 +272,7 @@ func TestPathSupportsExtendedAttributes(t *testing.T) {
 	}
 
 	// Test with an invalid path
-	_, err := PathSupportsExtendedAttributes("Z:\\NonExistentPath-UAS664da5s4dyu56das45f5as")
-	if err == nil {
-		t.Error("Expected an error for non-existent path, but got nil")
-	}
-}
-
-func TestGetVolumePathName(t *testing.T) {
-	tempDirVolume := filepath.VolumeName(os.TempDir())
-	testCases := []struct {
-		name           string
-		path           string
-		expectedPrefix string
-	}{
-		{
-			name:           "Root directory",
-			path:           os.Getenv("SystemDrive") + `\`,
-			expectedPrefix: os.Getenv("SystemDrive"),
-		},
-		{
-			name:           "Nested directory",
-			path:           os.Getenv("SystemDrive") + `\Windows\System32`,
-			expectedPrefix: os.Getenv("SystemDrive"),
-		},
-		{
-			name:           "Temp directory",
-			path:           os.TempDir() + `\`,
-			expectedPrefix: tempDirVolume,
-		},
-	}
-
-	for _, tc := range testCases {
-		t.Run(tc.name, func(t *testing.T) {
-			volumeName, err := GetVolumePathName(tc.path)
-			if err != nil {
-				t.Fatalf("Unexpected error: %v", err)
-			}
-			if !strings.HasPrefix(volumeName, tc.expectedPrefix) {
-				t.Errorf("Expected volume name to start with %s, but got %s", tc.expectedPrefix, volumeName)
-			}
-		})
-	}
-
-	// Test with an invalid path
-	_, err := GetVolumePathName("Z:\\NonExistentPath")
+	_, err := pathSupportsExtendedAttributes("Z:\\NonExistentPath-UAS664da5s4dyu56das45f5as")
 	if err == nil {
 		t.Error("Expected an error for non-existent path, but got nil")
 	}
