@@ -1,25 +1,20 @@
 package restic
 
 import (
-	"context"
+	"bytes"
 	"encoding/json"
 	"fmt"
 	"os"
-	"os/user"
 	"reflect"
 	"strconv"
 	"strings"
 	"sync"
-	"syscall"
 	"time"
 	"unicode/utf8"
 
 	"github.com/restic/restic/internal/errors"
 
-	"bytes"
-
 	"github.com/restic/restic/internal/debug"
-	"github.com/restic/restic/internal/fs"
 )
 
 // ExtendedAttribute is a tuple storing the xattr name and value for various filesystems.
@@ -71,10 +66,24 @@ func storeGenericAttributeType(attributeTypes ...GenericAttributeType) {
 	}
 }
 
+type NodeType string
+
+var (
+	NodeTypeFile      = NodeType("file")
+	NodeTypeDir       = NodeType("dir")
+	NodeTypeSymlink   = NodeType("symlink")
+	NodeTypeDev       = NodeType("dev")
+	NodeTypeCharDev   = NodeType("chardev")
+	NodeTypeFifo      = NodeType("fifo")
+	NodeTypeSocket    = NodeType("socket")
+	NodeTypeIrregular = NodeType("irregular")
+	NodeTypeInvalid   = NodeType("")
+)
+
 // Node is a file, directory or other item in a backup.
 type Node struct {
 	Name       string      `json:"name"`
-	Type       string      `json:"type"`
+	Type       NodeType    `json:"type"`
 	Mode       os.FileMode `json:"mode,omitempty"`
 	ModTime    time.Time   `json:"mtime,omitempty"`
 	AccessTime time.Time   `json:"atime,omitempty"`
@@ -114,19 +123,19 @@ func (n Nodes) Swap(i, j int)      { n[i], n[j] = n[j], n[i] }
 func (node Node) String() string {
 	var mode os.FileMode
 	switch node.Type {
-	case "file":
+	case NodeTypeFile:
 		mode = 0
-	case "dir":
+	case NodeTypeDir:
 		mode = os.ModeDir
-	case "symlink":
+	case NodeTypeSymlink:
 		mode = os.ModeSymlink
-	case "dev":
+	case NodeTypeDev:
 		mode = os.ModeDevice
-	case "chardev":
+	case NodeTypeCharDev:
 		mode = os.ModeDevice | os.ModeCharDevice
-	case "fifo":
+	case NodeTypeFifo:
 		mode = os.ModeNamedPipe
-	case "socket":
+	case NodeTypeSocket:
 		mode = os.ModeSocket
 	}
 
@@ -134,49 +143,6 @@ func (node Node) String() string {
 		mode|node.Mode, node.UID, node.GID, node.Size, node.ModTime, node.Name)
 }
 
-// NodeFromFileInfo returns a new node from the given path and FileInfo. It
-// returns the first error that is encountered, together with a node.
-func NodeFromFileInfo(path string, fi os.FileInfo, ignoreXattrListError bool) (*Node, error) {
-	mask := os.ModePerm | os.ModeType | os.ModeSetuid | os.ModeSetgid | os.ModeSticky
-	node := &Node{
-		Path:    path,
-		Name:    fi.Name(),
-		Mode:    fi.Mode() & mask,
-		ModTime: fi.ModTime(),
-	}
-
-	node.Type = nodeTypeFromFileInfo(fi)
-	if node.Type == "file" {
-		node.Size = uint64(fi.Size())
-	}
-
-	err := node.fillExtra(path, fi, ignoreXattrListError)
-	return node, err
-}
-
-func nodeTypeFromFileInfo(fi os.FileInfo) string {
-	switch fi.Mode() & os.ModeType {
-	case 0:
-		return "file"
-	case os.ModeDir:
-		return "dir"
-	case os.ModeSymlink:
-		return "symlink"
-	case os.ModeDevice | os.ModeCharDevice:
-		return "chardev"
-	case os.ModeDevice:
-		return "dev"
-	case os.ModeNamedPipe:
-		return "fifo"
-	case os.ModeSocket:
-		return "socket"
-	case os.ModeIrregular:
-		return "irregular"
-	}
-
-	return ""
-}
-
 // GetExtendedAttribute gets the extended attribute.
 func (node Node) GetExtendedAttribute(a string) []byte {
 	for _, attr := range node.ExtendedAttributes {
@@ -187,186 +153,6 @@ func (node Node) GetExtendedAttribute(a string) []byte {
 	return nil
 }
 
-// CreateAt creates the node at the given path but does NOT restore node meta data.
-func (node *Node) CreateAt(ctx context.Context, path string, repo BlobLoader) error {
-	debug.Log("create node %v at %v", node.Name, path)
-
-	switch node.Type {
-	case "dir":
-		if err := node.createDirAt(path); err != nil {
-			return err
-		}
-	case "file":
-		if err := node.createFileAt(ctx, path, repo); err != nil {
-			return err
-		}
-	case "symlink":
-		if err := node.createSymlinkAt(path); err != nil {
-			return err
-		}
-	case "dev":
-		if err := node.createDevAt(path); err != nil {
-			return err
-		}
-	case "chardev":
-		if err := node.createCharDevAt(path); err != nil {
-			return err
-		}
-	case "fifo":
-		if err := node.createFifoAt(path); err != nil {
-			return err
-		}
-	case "socket":
-		return nil
-	default:
-		return errors.Errorf("filetype %q not implemented", node.Type)
-	}
-
-	return nil
-}
-
-// RestoreMetadata restores node metadata
-func (node Node) RestoreMetadata(path string, warn func(msg string)) error {
-	err := node.restoreMetadata(path, warn)
-	if err != nil {
-		// It is common to have permission errors for folders like /home
-		// unless you're running as root, so ignore those.
-		if os.Geteuid() > 0 && errors.Is(err, os.ErrPermission) {
-			debug.Log("not running as root, ignoring permission error for %v: %v",
-				path, err)
-			return nil
-		}
-		debug.Log("restoreMetadata(%s) error %v", path, err)
-	}
-
-	return err
-}
-
-func (node Node) restoreMetadata(path string, warn func(msg string)) error {
-	var firsterr error
-
-	if err := lchown(path, int(node.UID), int(node.GID)); err != nil {
-		firsterr = errors.WithStack(err)
-	}
-
-	if err := node.restoreExtendedAttributes(path); err != nil {
-		debug.Log("error restoring extended attributes for %v: %v", path, err)
-		if firsterr == nil {
-			firsterr = err
-		}
-	}
-
-	if err := node.restoreGenericAttributes(path, warn); err != nil {
-		debug.Log("error restoring generic attributes for %v: %v", path, err)
-		if firsterr == nil {
-			firsterr = err
-		}
-	}
-
-	if err := node.RestoreTimestamps(path); err != nil {
-		debug.Log("error restoring timestamps for %v: %v", path, err)
-		if firsterr == nil {
-			firsterr = err
-		}
-	}
-
-	// Moving RestoreTimestamps and restoreExtendedAttributes calls above as for readonly files in windows
-	// calling Chmod below will no longer allow any modifications to be made on the file and the
-	// calls above would fail.
-	if node.Type != "symlink" {
-		if err := fs.Chmod(path, node.Mode); err != nil {
-			if firsterr == nil {
-				firsterr = errors.WithStack(err)
-			}
-		}
-	}
-
-	return firsterr
-}
-
-func (node Node) RestoreTimestamps(path string) error {
-	var utimes = [...]syscall.Timespec{
-		syscall.NsecToTimespec(node.AccessTime.UnixNano()),
-		syscall.NsecToTimespec(node.ModTime.UnixNano()),
-	}
-
-	if node.Type == "symlink" {
-		return node.restoreSymlinkTimestamps(path, utimes)
-	}
-
-	if err := syscall.UtimesNano(path, utimes[:]); err != nil {
-		return errors.Wrap(err, "UtimesNano")
-	}
-
-	return nil
-}
-
-func (node Node) createDirAt(path string) error {
-	err := fs.Mkdir(path, node.Mode)
-	if err != nil && !os.IsExist(err) {
-		return errors.WithStack(err)
-	}
-
-	return nil
-}
-
-func (node Node) createFileAt(ctx context.Context, path string, repo BlobLoader) error {
-	f, err := fs.OpenFile(path, os.O_CREATE|os.O_WRONLY|os.O_TRUNC, 0600)
-	if err != nil {
-		return errors.WithStack(err)
-	}
-
-	err = node.writeNodeContent(ctx, repo, f)
-	closeErr := f.Close()
-
-	if err != nil {
-		return err
-	}
-
-	if closeErr != nil {
-		return errors.WithStack(closeErr)
-	}
-
-	return nil
-}
-
-func (node Node) writeNodeContent(ctx context.Context, repo BlobLoader, f *os.File) error {
-	var buf []byte
-	for _, id := range node.Content {
-		buf, err := repo.LoadBlob(ctx, DataBlob, id, buf)
-		if err != nil {
-			return err
-		}
-
-		_, err = f.Write(buf)
-		if err != nil {
-			return errors.WithStack(err)
-		}
-	}
-
-	return nil
-}
-
-func (node Node) createSymlinkAt(path string) error {
-	if err := fs.Symlink(node.LinkTarget, path); err != nil {
-		return errors.WithStack(err)
-	}
-
-	return nil
-}
-
-func (node *Node) createDevAt(path string) error {
-	return mknod(path, syscall.S_IFBLK|0600, node.Device)
-}
-
-func (node *Node) createCharDevAt(path string) error {
-	return mknod(path, syscall.S_IFCHR|0600, node.Device)
-}
-
-func (node *Node) createFifoAt(path string) error {
-	return mkfifo(path, 0600)
-}
-
 // FixTime returns a time.Time which can safely be used to marshal as JSON. If
 // the timestamp is earlier than year zero, the year is set to zero. In the same
 // way, if the year is larger than 9999, the year is set to 9999. Other than
@@ -601,127 +387,6 @@ func deepEqual(map1, map2 map[GenericAttributeType]json.RawMessage) bool {
 	return true
 }
 
-func (node *Node) fillUser(stat *statT) {
-	uid, gid := stat.uid(), stat.gid()
-	node.UID, node.GID = uid, gid
-	node.User = lookupUsername(uid)
-	node.Group = lookupGroup(gid)
-}
-
-var (
-	uidLookupCache      = make(map[uint32]string)
-	uidLookupCacheMutex = sync.RWMutex{}
-)
-
-// Cached user name lookup by uid. Returns "" when no name can be found.
-func lookupUsername(uid uint32) string {
-	uidLookupCacheMutex.RLock()
-	username, ok := uidLookupCache[uid]
-	uidLookupCacheMutex.RUnlock()
-
-	if ok {
-		return username
-	}
-
-	u, err := user.LookupId(strconv.Itoa(int(uid)))
-	if err == nil {
-		username = u.Username
-	}
-
-	uidLookupCacheMutex.Lock()
-	uidLookupCache[uid] = username
-	uidLookupCacheMutex.Unlock()
-
-	return username
-}
-
-var (
-	gidLookupCache      = make(map[uint32]string)
-	gidLookupCacheMutex = sync.RWMutex{}
-)
-
-// Cached group name lookup by gid. Returns "" when no name can be found.
-func lookupGroup(gid uint32) string {
-	gidLookupCacheMutex.RLock()
-	group, ok := gidLookupCache[gid]
-	gidLookupCacheMutex.RUnlock()
-
-	if ok {
-		return group
-	}
-
-	g, err := user.LookupGroupId(strconv.Itoa(int(gid)))
-	if err == nil {
-		group = g.Name
-	}
-
-	gidLookupCacheMutex.Lock()
-	gidLookupCache[gid] = group
-	gidLookupCacheMutex.Unlock()
-
-	return group
-}
-
-func (node *Node) fillExtra(path string, fi os.FileInfo, ignoreXattrListError bool) error {
-	stat, ok := toStatT(fi.Sys())
-	if !ok {
-		// fill minimal info with current values for uid, gid
-		node.UID = uint32(os.Getuid())
-		node.GID = uint32(os.Getgid())
-		node.ChangeTime = node.ModTime
-		return nil
-	}
-
-	node.Inode = uint64(stat.ino())
-	node.DeviceID = uint64(stat.dev())
-
-	node.fillTimes(stat)
-
-	node.fillUser(stat)
-
-	switch node.Type {
-	case "file":
-		node.Size = uint64(stat.size())
-		node.Links = uint64(stat.nlink())
-	case "dir":
-	case "symlink":
-		var err error
-		node.LinkTarget, err = fs.Readlink(path)
-		node.Links = uint64(stat.nlink())
-		if err != nil {
-			return errors.WithStack(err)
-		}
-	case "dev":
-		node.Device = uint64(stat.rdev())
-		node.Links = uint64(stat.nlink())
-	case "chardev":
-		node.Device = uint64(stat.rdev())
-		node.Links = uint64(stat.nlink())
-	case "fifo":
-	case "socket":
-	default:
-		return errors.Errorf("unsupported file type %q", node.Type)
-	}
-
-	allowExtended, err := node.fillGenericAttributes(path, fi, stat)
-	if allowExtended {
-		// Skip processing ExtendedAttributes if allowExtended is false.
-		err = errors.CombineErrors(err, node.fillExtendedAttributes(path, ignoreXattrListError))
-	}
-	return err
-}
-
-func mkfifo(path string, mode uint32) (err error) {
-	return mknod(path, mode|syscall.S_IFIFO, 0)
-}
-
-func (node *Node) fillTimes(stat *statT) {
-	ctim := stat.ctim()
-	atim := stat.atim()
-	node.ChangeTime = time.Unix(ctim.Unix())
-	node.AccessTime = time.Unix(atim.Unix())
-}
-
 // HandleUnknownGenericAttributesFound is used for handling and distinguing between scenarios related to future versions and cross-OS repositories
 func HandleUnknownGenericAttributesFound(unknownAttribs []GenericAttributeType, warn func(msg string)) {
 	for _, unknownAttrib := range unknownAttribs {
@@ -746,11 +411,11 @@ func handleUnknownGenericAttributeFound(genericAttributeType GenericAttributeTyp
 	}
 }
 
-// handleAllUnknownGenericAttributesFound performs validations for all generic attributes in the node.
+// HandleAllUnknownGenericAttributesFound performs validations for all generic attributes of a node.
 // This is not used on windows currently because windows has handling for generic attributes.
 // nolint:unused
-func (node Node) handleAllUnknownGenericAttributesFound(warn func(msg string)) error {
-	for name := range node.GenericAttributes {
+func HandleAllUnknownGenericAttributesFound(attributes map[GenericAttributeType]json.RawMessage, warn func(msg string)) error {
+	for name := range attributes {
 		handleUnknownGenericAttributeFound(name, warn)
 	}
 	return nil
@@ -770,9 +435,8 @@ func checkGenericAttributeNameNotHandledAndPut(value GenericAttributeType) bool
 // The functions below are common helper functions which can be used for generic attributes support
 // across different OS.
 
-// genericAttributesToOSAttrs gets the os specific attribute from the generic attribute using reflection
-// nolint:unused
-func genericAttributesToOSAttrs(attrs map[GenericAttributeType]json.RawMessage, attributeType reflect.Type, attributeValuePtr *reflect.Value, keyPrefix string) (unknownAttribs []GenericAttributeType, err error) {
+// GenericAttributesToOSAttrs gets the os specific attribute from the generic attribute using reflection
+func GenericAttributesToOSAttrs(attrs map[GenericAttributeType]json.RawMessage, attributeType reflect.Type, attributeValuePtr *reflect.Value, keyPrefix string) (unknownAttribs []GenericAttributeType, err error) {
 	attributeValue := *attributeValuePtr
 
 	for key, rawMsg := range attrs {
@@ -796,20 +460,17 @@ func genericAttributesToOSAttrs(attrs map[GenericAttributeType]json.RawMessage,
 }
 
 // getFQKey gets the fully qualified key for the field
-// nolint:unused
 func getFQKey(field reflect.StructField, keyPrefix string) GenericAttributeType {
 	return GenericAttributeType(fmt.Sprintf("%s.%s", keyPrefix, field.Tag.Get("generic")))
 }
 
 // getFQKeyByIndex gets the fully qualified key for the field index
-// nolint:unused
 func getFQKeyByIndex(attributeType reflect.Type, index int, keyPrefix string) GenericAttributeType {
 	return getFQKey(attributeType.Field(index), keyPrefix)
 }
 
-// osAttrsToGenericAttributes gets the generic attribute from the os specific attribute using reflection
-// nolint:unused
-func osAttrsToGenericAttributes(attributeType reflect.Type, attributeValuePtr *reflect.Value, keyPrefix string) (attrs map[GenericAttributeType]json.RawMessage, err error) {
+// OSAttrsToGenericAttributes gets the generic attribute from the os specific attribute using reflection
+func OSAttrsToGenericAttributes(attributeType reflect.Type, attributeValuePtr *reflect.Value, keyPrefix string) (attrs map[GenericAttributeType]json.RawMessage, err error) {
 	attributeValue := *attributeValuePtr
 	attrs = make(map[GenericAttributeType]json.RawMessage)
 
@@ -833,7 +494,7 @@ func osAttrsToGenericAttributes(attributeType reflect.Type, attributeValuePtr *r
 		}
 
 		// Insert the field into the map
-		attrs[getFQKey(field, keyPrefix)] = json.RawMessage(fieldBytes)
+		attrs[getFQKey(field, keyPrefix)] = fieldBytes
 	}
 	return attrs, nil
 }
