@@ -256,6 +256,9 @@ func ApplyPolicy(list Snapshots, p ExpirePolicy) (keep, remove Snapshots, reason
 				if val != b.Last || nr == len(list)-1 {
 					debug.Log("keep %v %v, bucker %v, val %v\n", cur.Time, cur.id.Str(), i, val)
 					keepSnap = true
+					if val == b.Last && nr == len(list)-1 {
+						b.reason = fmt.Sprintf("oldest %v", b.reason)
+					}
 					buckets[i].Last = val
 					if buckets[i].Count > 0 {
 						buckets[i].Count--
@@ -275,6 +278,9 @@ func ApplyPolicy(list Snapshots, p ExpirePolicy) (keep, remove Snapshots, reason
 					if val != b.Last || nr == len(list)-1 {
 						debug.Log("keep %v, time %v, ID %v, bucker %v, val %v %v\n", b.reason, cur.Time, cur.id.Str(), i, val, b.Last)
 						keepSnap = true
+						if val == b.Last && nr == len(list)-1 {
+							b.reason = fmt.Sprintf("oldest %v", b.reason)
+						}
 						bucketsWithin[i].Last = val
 						keepSnapReasons = append(keepSnapReasons, fmt.Sprintf("%v %v", b.reason, b.Within))
 					}
