@@ -2,6 +2,7 @@ package restorer
 
 import (
 	"context"
+	"fmt"
 	"path/filepath"
 	"sync"
 
@@ -9,6 +10,7 @@ import (
 
 	"github.com/restic/restic/internal/debug"
 	"github.com/restic/restic/internal/errors"
+	"github.com/restic/restic/internal/feature"
 	"github.com/restic/restic/internal/repository"
 	"github.com/restic/restic/internal/restic"
 	"github.com/restic/restic/internal/ui/restore"
@@ -41,12 +43,15 @@ type packInfo struct {
 }
 
 type blobsLoaderFn func(ctx context.Context, packID restic.ID, blobs []restic.Blob, handleBlobFn func(blob restic.BlobHandle, buf []byte, err error) error) error
+type startWarmupFn func(context.Context, restic.IDSet) (restic.WarmupJob, error)
 
 // fileRestorer restores set of files
 type fileRestorer struct {
 	idx         func(restic.BlobType, restic.ID) []restic.PackedBlob
 	blobsLoader blobsLoaderFn
 
+	startWarmup startWarmupFn
+
 	workerCount int
 	filesWriter *filesWriter
 	zeroChunk   restic.ID
@@ -58,6 +63,7 @@ type fileRestorer struct {
 	dst   string
 	files []*fileInfo
 	Error func(string, error) error
+	Info  func(string)
 }
 
 func newFileRestorer(dst string,
@@ -66,6 +72,7 @@ func newFileRestorer(dst string,
 	connections uint,
 	sparse bool,
 	allowRecursiveDelete bool,
+	startWarmup startWarmupFn,
 	progress *restore.Progress) *fileRestorer {
 
 	// as packs are streamed the concurrency is limited by IO
@@ -74,6 +81,7 @@ func newFileRestorer(dst string,
 	return &fileRestorer{
 		idx:                  idx,
 		blobsLoader:          blobsLoader,
+		startWarmup:          startWarmup,
 		filesWriter:          newFilesWriter(workerCount, allowRecursiveDelete),
 		zeroChunk:            repository.ZeroChunk(),
 		sparse:               sparse,
@@ -82,6 +90,7 @@ func newFileRestorer(dst string,
 		workerCount:          workerCount,
 		dst:                  dst,
 		Error:                restorerAbortOnAllErrors,
+		Info:                 func(_ string) {},
 	}
 }
 
@@ -192,6 +201,19 @@ func (r *fileRestorer) restoreFiles(ctx context.Context) error {
 	// drop no longer necessary file list
 	r.files = nil
 
+	if feature.Flag.Enabled(feature.S3Restore) {
+		warmupJob, err := r.startWarmup(ctx, restic.NewIDSet(packOrder...))
+		if err != nil {
+			return err
+		}
+		if warmupJob.HandleCount() != 0 {
+			r.Info(fmt.Sprintf("warming up %d packs from cold storage, this may take a while...", warmupJob.HandleCount()))
+			if err := warmupJob.Wait(ctx); err != nil {
+				return err
+			}
+		}
+	}
+
 	wg, ctx := errgroup.WithContext(ctx)
 	downloadCh := make(chan *packInfo)
 
@@ -337,7 +359,7 @@ func (r *fileRestorer) downloadBlobs(ctx context.Context, packID restic.ID,
 			}
 			for file, offsets := range blob.files {
 				for _, offset := range offsets {
-					// avoid long cancelation delays for frequently used blobs
+					// avoid long cancellation delays for frequently used blobs
 					if ctx.Err() != nil {
 						return ctx.Err()
 					}
@@ -377,5 +399,5 @@ func (r *fileRestorer) reportBlobProgress(file *fileInfo, blobSize uint64) {
 	if file.state == nil {
 		action = restore.ActionFileRestored
 	}
-	r.progress.AddProgress(file.location, action, uint64(blobSize), uint64(file.size))
+	r.progress.AddProgress(file.location, action, blobSize, uint64(file.size))
 }
