@@ -10,20 +10,20 @@ type HardlinkKey struct {
 }
 
 // HardlinkIndex contains a list of inodes, devices these inodes are one, and associated file names.
-type HardlinkIndex struct {
+type HardlinkIndex[T any] struct {
 	m     sync.Mutex
-	Index map[HardlinkKey]string
+	Index map[HardlinkKey]T
 }
 
 // NewHardlinkIndex create a new index for hard links
-func NewHardlinkIndex() *HardlinkIndex {
-	return &HardlinkIndex{
-		Index: make(map[HardlinkKey]string),
+func NewHardlinkIndex[T any]() *HardlinkIndex[T] {
+	return &HardlinkIndex[T]{
+		Index: make(map[HardlinkKey]T),
 	}
 }
 
-// Has checks wether the link already exist in the index.
-func (idx *HardlinkIndex) Has(inode uint64, device uint64) bool {
+// Has checks whether the link already exist in the index.
+func (idx *HardlinkIndex[T]) Has(inode uint64, device uint64) bool {
 	idx.m.Lock()
 	defer idx.m.Unlock()
 	_, ok := idx.Index[HardlinkKey{inode, device}]
@@ -32,25 +32,25 @@ func (idx *HardlinkIndex) Has(inode uint64, device uint64) bool {
 }
 
 // Add adds a link to the index.
-func (idx *HardlinkIndex) Add(inode uint64, device uint64, name string) {
+func (idx *HardlinkIndex[T]) Add(inode uint64, device uint64, value T) {
 	idx.m.Lock()
 	defer idx.m.Unlock()
 	_, ok := idx.Index[HardlinkKey{inode, device}]
 
 	if !ok {
-		idx.Index[HardlinkKey{inode, device}] = name
+		idx.Index[HardlinkKey{inode, device}] = value
 	}
 }
 
-// GetFilename obtains the filename from the index.
-func (idx *HardlinkIndex) GetFilename(inode uint64, device uint64) string {
+// Value obtains the filename from the index.
+func (idx *HardlinkIndex[T]) Value(inode uint64, device uint64) T {
 	idx.m.Lock()
 	defer idx.m.Unlock()
 	return idx.Index[HardlinkKey{inode, device}]
 }
 
 // Remove removes a link from the index.
-func (idx *HardlinkIndex) Remove(inode uint64, device uint64) {
+func (idx *HardlinkIndex[T]) Remove(inode uint64, device uint64) {
 	idx.m.Lock()
 	defer idx.m.Unlock()
 	delete(idx.Index, HardlinkKey{inode, device})
