@@ -4,7 +4,7 @@
 package selfupdate
 
 // Remove the target binary.
-func removeResticBinary(dir, target string) error {
+func removeResticBinary(_, _ string) error {
 	// removed on rename on this platform
 	return nil
 }
