@@ -33,7 +33,7 @@ func (p *mockPrinter) CompleteItem(messageType string, _ string, _ archiver.Item
 }
 
 func (p *mockPrinter) ReportTotal(_ time.Time, _ archiver.ScanStats) {}
-func (p *mockPrinter) Finish(id restic.ID, _ time.Time, _ *archiver.Summary, _ bool) {
+func (p *mockPrinter) Finish(id restic.ID, _ *archiver.Summary, _ bool) {
 	p.Lock()
 	defer p.Unlock()
 
@@ -55,10 +55,10 @@ func TestProgress(t *testing.T) {
 	prog.CompleteBlob(1024)
 
 	// "dir unchanged"
-	node := restic.Node{Type: "dir"}
+	node := restic.Node{Type: restic.NodeTypeDir}
 	prog.CompleteItem("foo", &node, &node, archiver.ItemStats{}, 0)
 	// "file new"
-	node.Type = "file"
+	node.Type = restic.NodeTypeFile
 	prog.CompleteItem("foo", nil, &node, archiver.ItemStats{}, 0)
 
 	time.Sleep(10 * time.Millisecond)
